;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "vs-dark-theme" "20251111.322"
  "Visual Studio IDE dark theme."
  '((emacs "24.1"))
  :url "https://github.com/emacs-vs/vs-dark-theme"
  :commit "3618c438b8eba8f89cba760b546c3d0f69c9d167"
  :revdesc "3618c438b8eb"
  :keywords '("faces"))
